@@ -1,15 +1,16 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
+# Copyright (c) 2008-2020 pyglet contributors
 # All rights reserved.
-# 
+#
 # Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions 
+# modification, are permitted provided that the following conditions
 # are met:
 #
 #  * Redistributions of source code must retain the above copyright
 #    notice, this list of conditions and the following disclaimer.
-#  * Redistributions in binary form must reproduce the above copyright 
+#  * Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in
 #    the documentation and/or other materials provided with the
 #    distribution.
@@ -32,7 +33,7 @@
 # POSSIBILITY OF SUCH DAMAGE.
 # ----------------------------------------------------------------------------
 
-'''Application-wide functionality.
+"""Application-wide functionality.
 
 Applications
 ------------
@@ -61,84 +62,53 @@ default policy is to wait until all windows are closed)::
         event_loop.exit()
 
 .. versionadded:: 1.1
-'''
-from builtins import object
-
-__docformat__ = 'restructuredtext'
-__version__ = '$Id$'
+"""
 
 import sys
 import weakref
 
-_is_epydoc = hasattr(sys, 'is_epydoc') and sys.is_epydoc
+from pyglet.app.base import EventLoop
+from pyglet import compat_platform
+
+_is_pyglet_doc_run = hasattr(sys, "is_pyglet_doc_run") and sys.is_pyglet_doc_run
+
+
+if _is_pyglet_doc_run:
+    from pyglet.app.base import PlatformEventLoop
+else:
+    if compat_platform == 'darwin':
+        from pyglet.app.cocoa import CocoaEventLoop as PlatformEventLoop
+    elif compat_platform in ('win32', 'cygwin'):
+        from pyglet.app.win32 import Win32EventLoop as PlatformEventLoop
+    else:
+        from pyglet.app.xlib import XlibEventLoop as PlatformEventLoop
+
 
 class AppException(Exception):
     pass
 
-class WeakSet(object):
-    '''Set of objects, referenced weakly.
 
-    Adding an object to this set does not prevent it from being garbage
-    collected.  Upon being garbage collected, the object is automatically
-    removed from the set.
-    '''
-    def __init__(self):
-        self._dict = weakref.WeakKeyDictionary()
-
-    def add(self, value):
-        self._dict[value] = True
-
-    def remove(self, value):
-        # Value might be removed already if this is during __del__ of the item.
-        self._dict.pop(value, None)
-
-    def pop(self):
-        value, _ = self._dict.popitem()
-        return value
-
-    def __iter__(self):
-        for key in self._dict.keys():
-            yield key
-
-    def __contains__(self, other):
-        return other in self._dict
-
-    def __len__(self):
-        return len(self._dict)
-
-
-displays = WeakSet()
-'''Set of all open displays.  Instances of :class:`pyglet.canvas.Display` 
-are automatically added to this set upon construction.  The set uses weak 
-references, so displays are removed from the set when they are no longer 
-referenced.
-
-:deprecated: Use :func:`pyglet.canvas.get_display`.
-
-:type: :class:`WeakSet`
-'''
-
-
-windows = WeakSet()
-'''Set of all open windows (including invisible windows).  Instances of
+windows = weakref.WeakSet()
+"""Set of all open windows (including invisible windows).  Instances of
 :class:`pyglet.window.Window` are automatically added to this set upon 
 construction. The set uses weak references, so windows are removed from 
 the set when they are no longer referenced or are closed explicitly.
-'''
+"""
 
 
 def run():
-    '''Begin processing events, scheduled functions and window updates.
+    """Begin processing events, scheduled functions and window updates.
 
     This is a convenience function, equivalent to::
 
         pyglet.app.event_loop.run()
 
-    '''
+    """
     event_loop.run()
 
+
 def exit():
-    '''Exit the application event loop.
+    """Exit the application event loop.
 
     Causes the application event loop to finish, if an event loop is currently
     running.  The application may not necessarily exit (for example, there may
@@ -148,35 +118,16 @@ def exit():
 
         event_loop.exit()
 
-    '''
+    """
     event_loop.exit()
 
-from pyglet.app.base import EventLoop
-from pyglet import compat_platform
-if _is_epydoc:
-    from pyglet.app.base import PlatformEventLoop
-else:
-    if compat_platform == 'darwin':
-        from pyglet import options as pyglet_options
-        if pyglet_options['darwin_cocoa']:
-            from pyglet.app.cocoa import CocoaEventLoop as PlatformEventLoop
-        else:
-            from pyglet.app.carbon import CarbonEventLoop as PlatformEventLoop
-    elif compat_platform in ('win32', 'cygwin'):
-        from pyglet.app.win32 import Win32EventLoop as PlatformEventLoop
-    else:
-        from pyglet.app.xlib import XlibEventLoop as PlatformEventLoop
-
-
 
 #: The global event loop.  Applications can replace this
 #: with their own subclass of :class:`EventLoop` before calling 
 #: :meth:`EventLoop.run`.
 event_loop = EventLoop()
 
+#: The platform-dependent event loop.
+#: Applications must not subclass or replace this :class:`PlatformEventLoop`
+#: object.
 platform_event_loop = PlatformEventLoop()
-
-"""The platform-dependent event loop. 
-Applications must not subclass or replace this :class:`PlatformEventLoop` 
-object.
-"""
\ No newline at end of file
